@@ -46,8 +46,9 @@ else:
 	from clouderizer.utils import check_aws_cli_exists, check_sam_cli_exists
 	BASE_URL="https://showcase.clouderizer.com"
 
+BASE_URL="https://showcase2.clouderizer.com"
 SYNC_URL="https://serverless.clouderizer.com/function/"
-
+# BASE_URL="https://20a5-14-98-21-242.ngrok.io"
 #upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
 #get_user_bucket_endpoint = BASE_URL + '/api/awsconfig/getbucket'
 
@@ -90,6 +91,7 @@ SUPPORTED_NOTEBOOK_EXECUTION_TYPES=['python']
 SUPPORTED_INFRA_TYPES=['standard','highmemory','gpu']
 LAMBDA_SUPPORTED_INFRA_TYPES=['standard','highmemory']
 SUPPORTED_IMAGE_TYPES=['standard','torch','tensorflow']
+LINUX_USERS=['root','app']
 
 SCOPES=['https://www.googleapis.com/auth/userinfo.profile','https://www.googleapis.com/auth/userinfo.email' ,'openid']
 
@@ -275,9 +277,11 @@ def generate_pipreqs_str(args):
 	return pipreqs_str
 
 
-def run_pipreqs(args):
+def run_pipreqs(args, savepath):
 	# print('pipreqs {}'.format(args))
-	os.system('pipreqs --no-pin {} 2> /dev/null'.format(args))
+	# print(args, savepath)
+	#  2> /dev/null
+	os.system('pipreqs {} --savepath {} 2> /dev/null'.format(args, savepath))
 
 
 def get_ipynb_files(path, ignore_dirs=None):
@@ -350,7 +354,9 @@ def pipreqsnb_main(input_path):
 					valid_lines = clean_invalid_lines_from_list_of_lines(cell['source'])
 					source = ''.join(valid_lines)
 					imports += get_import_string_from_source(source)
+
 		except Exception as e:
+			print(e)
 			pass
 			# print("Couldn't fetch dependencies from notebook "+ input_path)
 			# print("Exception occurred while working on file {}, cell {}/{}".format(nb_file, n_cell + 1, len(nb['cells'])))
@@ -363,13 +369,18 @@ def pipreqsnb_main(input_path):
 		args.path = temp_path
 	try:
 		os.makedirs(temp_path, exist_ok=True)
+		# print(temp_file)
 		with open(temp_file, 'a') as temp_file:
 			for import_line in imports:
 				temp_file.write('{}\n'.format(import_line))
 		pipreqs_args = generate_pipreqs_str(args)
-		run_pipreqs(pipreqs_args)
-		shutil.rmtree(temp_path)
+
+		run_pipreqs(temp_path, input_path+"requirements.txt")
+
+		#os.system("cat {}".format(temp_file))
+		#shutil.rmtree(temp_path)
 	except Exception as e:
+		print(e)
 		if os.path.isfile(temp_file):
 			os.remove(temp_file)
 		raise e
@@ -378,6 +389,7 @@ def pipreqsnb_main(input_path):
 
 def upload_to_showcase(file_name,file_loc,company,auth_token):
 	print("Uploading to Clouderizer.....")
+	# print(BASE_URL)
 	upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
 	resp=requests.post(upload_endpoint,json={
 			"type":"put",
@@ -521,7 +533,7 @@ def create_serving_project(filename,companyid,auth_token,projectName=None,inputA
 		return create_serving_project(filename,companyid,auth_token,retry)
 
 
-def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,retry=0,is_lambda_deploy="false"):
+def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,retry=0,is_lambda_deploy="false",startup_command_list=[]):
 	# print("Inside")
 	company=servingproject["company"]
 	auth_headers={"Authorization": "Bearer "+auth_token}
@@ -563,6 +575,7 @@ def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPac
 		"training": training,
 		"userreqs": pipPackages,
 		"pipPackages": pipPackages,
+		"startupCommands" : startup_command_list,
 		"preprocessEnabled": preprocessEnabled,
 		"postprocessEnabled":postprocessEnabled,
 		"preprocessCodePath":preprocessS3Path,
@@ -587,7 +600,7 @@ def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPac
 			return "Could not create project"
 		
 		sleep(5*retry)
-		return create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess,postprocess,predict,retry)
+		return create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess,postprocess,predict,retry=retry,is_lambda_deploy=is_lambda_deploy,startup_command_list=startup_command_list)
 
 def fetchprojectconfig(servingproject):
 	# print("Serving project", servingproject)
@@ -741,7 +754,8 @@ def get_from_pipreqs(notebook_path,pyFile=False):
 		os.system("rm {LOCAL_DIR}/req/* >/dev/null 2>&1".format(LOCAL_DIR=LOCAL_DIR))
 
 	if not pyFile:
-		os.system("jupyter nbconvert --Application.log_level=50 {NOTEBOOK_PATH} --to script --output-dir={LOCAL_DIR}/req".format(NOTEBOOK_PATH=notebook_path,LOCAL_DIR=LOCAL_DIR))
+		os.system("jupyter nbconvert --Application.log_level=50 {NOTEBOOK_PATH} --to python --output-dir={LOCAL_DIR}/req".format(NOTEBOOK_PATH=notebook_path,LOCAL_DIR=LOCAL_DIR))
+		# os.system("jupyter nbconvert --to python {NOTEBOOK_PATH} --output-dir={LOCAL_DIR}/req".format(NOTEBOOK_PATH=notebook_path,LOCAL_DIR=LOCAL_DIR))
 	else:
 		os.system("cp ${NOTEBOOK_PATH} {LOCAL_DIR}/req/")
 	os.system("pipreqs --no-pin {LOCAL_DIR}/req &> /dev/null".format(LOCAL_DIR=LOCAL_DIR))
@@ -843,14 +857,14 @@ def find_full_project_name(name):
 	
 	return name
 
-def invoke_publishproject(servingprojectid, infra, auth_token, invokepublishproject=True):
+def invoke_publishproject(servingprojectid, infra, auth_token, invokepublishproject=True, linux_user="app"):
 	# print(servingprojectid)
 	invoke_url = BASE_URL+'/api/servingproject/publishproject'
 	if not invokepublishproject:
 		invoke_url = BASE_URL+'/api/servingproject/publishprojectlambda'
 
 	auth_headers={"Authorization": "Bearer "+auth_token}
-	publishproject=requests.post(invoke_url,headers=auth_headers,data={"projectId":servingprojectid,"infratype":infra})
+	publishproject=requests.post(invoke_url,headers=auth_headers,data={"projectId":servingprojectid,"infratype":infra,"privileged_mode":linux_user})
 	
 	if publishproject.status_code==401:
 		return "Authentication was unsuccessful! try cldz login"
@@ -917,6 +931,18 @@ def wait_for_saved_successfully(servingprojectid,auth_token,retry=0):
 
 		return wait_for_saved_successfully(servingprojectid,auth_token,retry+1)
 
+def parse_startup_scripts(startup_script_path):
+	try:
+		fd = open(startup_script_path, 'r')
+		command_list = fd.readlines()
+		command_list = [command.replace("\n","") for command in command_list]
+		print("Startup commands "  + str(command_list))
+		fd.close()
+		return command_list
+	except Exception as e:
+		print("Could not parse startup scripts file")
+		exit(0)
+
 def parse_requirements(requirements_path):
 	try:
 		packages=[]
@@ -1207,7 +1233,7 @@ class Clouderizer(object):
 			print("Some error occurred")
 
 
-	def start(self, name,infra="standard",image="standard"):
+	def start(self, name,infra="standard",image="standard",user="app"):
 		global loadingDisplay
 		if not name:
 			print("Choose a specific project!")
@@ -1226,6 +1252,11 @@ class Clouderizer(object):
 			print("Available image types : standard, torch, tensorflow")
 			return
 
+		if user not in LINUX_USERS:
+			print("--user is not an accepted value")
+			print("Available linux users : app, root (default: app)")
+			return
+
 		name=find_full_project_name(name)
 
 		servingprojectsurl=BASE_URL+'/api/servingproject?where={"name":"%s","company":"%s"}' % (name,creds['cid'])
@@ -1237,7 +1268,7 @@ class Clouderizer(object):
 			print("Could not find project, try again")
 			return
 
-		publishproject=invoke_publishproject(serving_project[0]["id"],infra,creds["token"])
+		publishproject=invoke_publishproject(serving_project[0]["id"],infra,creds["token"],linux_user=user)
 		print("Publishing the project...this might take a while")
 
 		if type(publishproject)==dict and "success" in publishproject and publishproject["success"]==True:
@@ -1833,7 +1864,7 @@ class Clouderizer(object):
 					publishproject=invoke_publishproject(servingproject["id"],"standard",auth_token,False)
 					# print(publishproject)
 
-	def quickdeploy(self,file_path=None,requirements=None,predict=None,preprocess=None,postprocess=None,model_type=None,notebook_type=None,infra="standard",image="standard",schema=None):
+	def quickdeploy(self,file_path=None,requirements=None,predict=None,preprocess=None,postprocess=None,model_type=None,notebook_type=None,infra="standard",image="standard",schema=None,user="app",startup_scripts=None):
 	# def deploy(self,first_path=None,second_path=None,third_path=None,model_type=None,notebook_type=None,enable_gpu=None):
 		global loadingDisplay
 		creds=self.loggedin()
@@ -1850,6 +1881,11 @@ class Clouderizer(object):
 			print("Available image types : standard, torch, tensorflow")
 			return
 
+		if user not in LINUX_USERS:
+			print("--user is not an accepted value")
+			print("Available linux users : app, root (default: app)")
+			return
+
 		execution_type="notebook"
 		subtype="pythonscore"
 
@@ -1898,15 +1934,13 @@ class Clouderizer(object):
 			notebook_path=file_path
 
 			checkPathExists(notebook_path)
-			# if not os.path.exists(notebook_path):
-			# 	print("Notebook path does not exist "+ notebook_path)
-			# 	return
 
 			if not notebook_path.endswith(".ipynb"):
 				print("File path does not point to a jupyter notebook" + notebook_path)
 				return
 
 			checkPathExists(requirements_path)
+			checkPathExists(startup_scripts)
 			# if (requirements_path!=None and not os.path.exists(requirements_path)):
 			# 	print("Notebook path does not exist "+ requirements_path)
 			# 	return
@@ -1916,9 +1950,14 @@ class Clouderizer(object):
 			else:
 				pipPackages=get_from_pipreqsnb(notebook_path)
 
+			startup_command_list=[]
+			if startup_scripts!=None:
+				startup_command_list=parse_startup_scripts(startup_scripts)
+
 			print("TYPE : NOTEBOOK")
 			print("NOTEBOOK FILE PATH : " + notebook_path)
 			print("FETCHED PIP PACKAGES : ", pipPackages)		
+			print("FETCHED STARTUP COMMANDS LIST : ", startup_command_list)
 
 			print("Please check the above project attributes.")
 			display_timer("In case something looks wrong, press Ctrl + C and try again with correct values. Deployment will continue in ",10)	
@@ -1933,7 +1972,7 @@ class Clouderizer(object):
 				uploadmodel_resp=upload_to_showcase(s3Path,notebook_path,servingproject["company"],auth_token)
 				if uploadmodel_resp=="Success":
 					try:
-						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,image)
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,image,startup_command_list=startup_command_list)
 					except Exception as e:
 						print(e)
 						print("Some exception occurred while preparing your notebook, please try again!")
@@ -1941,7 +1980,7 @@ class Clouderizer(object):
 
 					if type(servingmodel)==dict and "id" in servingmodel:    
 						print("Project created!")
-						publishproject=invoke_publishproject(servingproject["id"],infra,auth_token)
+						publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,linux_user=user)
 						# print(publishproject)
 						print("Publishing the project...this might take a while")
 						if type(publishproject)==dict and "success" in publishproject and publishproject["success"]==True:
@@ -1993,9 +2032,11 @@ class Clouderizer(object):
 				return
 
 			checkPathExists(model_path)
-			# if not os.path.exists(model_path):
-			# 	print("Model path does not exist "+ model_path)
-			# 	return
+			checkPathExists(startup_scripts)
+			
+			startup_command_list=[]
+			if startup_scripts!=None:
+				startup_command_list=parse_startup_scripts(startup_scripts)
 
 			if preprocess_path:
 				checkPathExists(preprocess_path)
@@ -2095,7 +2136,7 @@ class Clouderizer(object):
 						deployment_model_type="automl"
 						if subtype in ["python","onnx","pythonscore"]:
 							deployment_model_type="regular"
-						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"false",deployment_model_type,subtype,image,preprocess=preprocess_path,postprocess=postprocess_path,predict=predict_path)
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"false",deployment_model_type,subtype,image,preprocess=preprocess_path,postprocess=postprocess_path,predict=predict_path,startup_command_list=startup_command_list)
 					except Exception as e:
 						print(e)
 						print("Some exception occurred while preparing your model, please try again!")						
@@ -2109,7 +2150,7 @@ class Clouderizer(object):
 								print("Some error occurred while fetching attributes")
 								self.delete(servingproject["name"])
 								return
-						publishproject=invoke_publishproject(servingproject["id"],infra,auth_token)
+						publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,linux_user=user)
 						# print(publishproject)
 						print("Publishing the project...this might take a while")
 						if type(publishproject)==dict and "success" in publishproject and publishproject["success"]==True:
@@ -2382,7 +2423,7 @@ class Clouderizer(object):
 						print("Some exception occurred while preparing your notebook, please try again!")
 						return
 
-					publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,False)
+					publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,invokepublishproject=False)
 
 					if type(servingmodel)==dict and "id" in servingmodel:
 						print("Project created!")
@@ -2535,7 +2576,7 @@ class Clouderizer(object):
 						print("Some exception occurred while preparing your model, please try again!")						
 						return
 
-					publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,False)					
+					publishproject=invoke_publishproject(servingproject["id"],infra,auth_token,invokepublishproject=False)					
 
 					if type(servingmodel)==dict and "id" in servingmodel:    
 						print("Project created!")
