@@ -18,7 +18,6 @@ import shutil
 import uuid
 import logging
 from pathlib import Path
-from clouderizer_beta import globals
 
 # import boto3
 
@@ -27,6 +26,13 @@ try:
     from ruamel.yaml import YAML
 except ModuleNotFoundError:
     from ruamel_yaml import YAML
+
+dir_name = os.path.dirname(os.path.realpath(__file__)).split("/")[-1]
+if dir_name == "clouderizer_beta" or "beta" in dir_name:
+    from clouderizer_beta import globals
+else:
+    from clouderizer import globals
+
 # from bentoml.exceptions import (
 #     BentoMLException,
 #     InvalidArgument,
