@@ -27,7 +27,12 @@ import requests
 # from bentoml.exceptions import BentoMLException
 # from bentoml.yatai.deployment.aws_utils import call_sam_command
 import subprocess
-from clouderizer_beta import globals
+
+dir_name = os.path.dirname(os.path.realpath(__file__)).split("/")[-1]
+if dir_name == "clouderizer_beta" or "beta" in dir_name:
+    from clouderizer_beta import globals
+else:
+    from clouderizer import globals
 
 logger = logging.getLogger(__name__)
 
